tic
%% Suppress unwanted error warnings and check for mexfiles
warning('off','MATLAB:polyfit:RepeatedPointsOrRescale');
create_mex;
%% Path and name
%Define path to data or select it in window
pathtofile  = '/Volumes/Seagate Backup Plus Drive/Mathieu_Data';
%[~,pathtofile] = uigetfile('*');
%Define what the generic name of the files is in global_filename
global_filename = 'GW207';

%% Information parsing
%Create the im_info structure. Modify default options in analysis_options.m
im_info = im_info_full_creation(global_filename,pathtofile);
%Override any parameter that has been created by automatic file parsing
im_info_override;
%Save the im_info.mat structure
save(strcat(im_info.path,'/','im_info.mat'),'im_info');

%% Actual segmentation and spot detection
%Segment cells over time using phase information
mainplot=figure();
%Go through all files in the folder
for imnum=1:im_info.nbGrid
    
    %Define the file name
    filename = define_filename(im_info, imnum);
    %Load the first phase stack
    FinalImage = TiffLoad_partial_multi(filename, im_info.path, im_info, im_info.phasecol, 1);%segm_settings.start_time);
    %Find the plane inclination of the field of view
    C = correlation_imaging_init(FinalImage, im_info.z_step*10^3, im_info.sample_thickness);
    im_info.im_tilt(imnum,:)=C;
    im_info.current_tilt=C;
    
    save(strcat(im_info.path,'/','im_info.mat'),'im_info');
    
    %% Segmentation steps 
    %Rough initial segmentation
    segm_time=struct('valx',[],'valy',[],'cell_info',[]);
    for t=im_info.start_time:im_info.end_time
        segm_time = simple_segmentation_time(im_info, filename, segm_time, t, mainplot);
        save(strcat(im_info.path,'/',filename,'_simpleseg.mat'),'segm_time');
    end
    %Split and merge cells by using temporal information.
    segm_time = rearrange(segm_time, im_info);
    %Assemble cells into lineages and save the resulting information
    snake_info = create_lineage(segm_time, im_info);
    save(strcat(im_info.path,'/',filename,'_snake_rough.mat'), 'snake_info');
    %Smooth the cells using Fourier analysis and tube-snake
    for t=im_info.start_time:1:im_info.end_time-2
        snake_info = smooth_time(snake_info,im_info,filename,t);
        save(strcat(im_info.path,'/',filename,'_snake_smooth.mat'),'snake_info');
    end
    
    %% Calculate cell generations and features
    [snake_info, allgenerations, allgenerations_tree] = snake_features(snake_info, im_info, filename);
    save(strcat(im_info.path,'/',filename,'_snake_features.mat'),'snake_info','allgenerations','allgenerations_tree');
    
    %% Detect the spots and assign them to their cell
    empty_struct = struct('x', [], 'y', [], 'z', [], 'A', [],'c', [], 'sigmaxy', [], 'sigmaz', [], 'loglikeratio',[]);
    spot_info=cell(1,size(im_info.spotcol,2));
    for color=1:size(im_info.spotcol,2)
        colorpos = im_info.spotcol(color);
        for time=im_info.start_time:im_info.end_time-2
            strcat('time: ', num2str(time))
            if mod(time-1,im_info.colorperiod(colorpos))==0
                [spot_info{color}(time), ~] = spot_detection(im_info, snake_info, filename, colorpos, time, 'mainplot',mainplot);
            else
                spot_info{color}(time) = empty_struct;
            end
        end
    end
    
    %% Save the spot detection information
    save(strcat(im_info.path,'/',filename,'_spots.mat'),'spot_info');
    
    %% Assign spots to cells and save definitive structure
    snake_info = assign_spots_to_cells(snake_info, spot_info, im_info, filename);
        
    oldfolder=cd(im_info.path);
    save(strcat(filename,'_snake_info.mat'),'snake_info','allgenerations','allgenerations_tree');
    cd(oldfolder)
    
end
%%
toc
