function [ test_YZslice, xbar, ybar ] = IntensityWeightedCentroid_Stack(name_tiff_stack, steps_per_tp, start_y, end_y)
%   Function makes end-on images of your 3D slice starting from the top
%   of 2D image. 'wPhase' means there is a circle drawin on the nucleoid
%   data corresponding to the width of the center phase image at that slice 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Read in images from folder
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fname = name_tiff_stack;
info = imfinfo(fname);
num_images = numel(info);
for k = 1:num_images
image_stack(:,:,k) = imread(fname,k);
end

%Determine the total number of time points in file
num_tp = length(image_stack(1,1,:))/steps_per_tp;

%reshape the stack to make individual time points
stack_array = reshape(image_stack,length(image_stack(:,1,1)), length(image_stack(1,:,1)), steps_per_tp, num_tp);
        

%Make Z projections for each time point
for k =1:num_tp
    z_proj(:,:,k) = sum(stack_array(:,:,:,k),3);
end

%Determine location of highest intensity in the Z-projection
[maxval,idx] = max(z_proj(:,:,:),[],2);
y_idx_vals = 1:length(idx)';
spline_y = 0:.5:length(idx)';
%xx = spline(y_idx_vals,idx(:,1,r),spline_y)


%Plot z projection and indicate pixels of highest intensity (down the tube)
for r = 1:num_tp
    figure;imagesc(z_proj(:,:,r))
    colormap(hot);
    xx = spline(y_idx_vals,idx(:,1,r),spline_y);
    smooth_x = smooth(idx(:,1,r),5);
    hold on;plot(idx(:,1,r),y_idx_vals,'*')
    %hold on;plot(xx,spline_y,'r','LineWidth',5)
    hold on;plot(smooth_x,y_idx_vals,'b','LineWidth',4);
end




%%Make YZ slices
for t = 1:length(stack_array(1,1,1,:))
    for a = 1:length(stack_array(:,1,1,1))
        xz(:,:,a,t) = squeeze(stack_array(a,:,:,t)); %but xz needs to be xz'
    end
end
test_YZslice = xz(:,:,start_y:end_y,:);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Code below can be used to save YZ slices from each timepoint
% Not a great way to do it (code is garbage)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mydir = pwd;
% for j = 1:length(test_YZslice(1,1,1,:))
%     new_dir = mkdir(num2str(j));
%     save_dir = strcat(mydir,'/',num2str(new_dir));
%     cd(save_dir);
%     for k = 3:length(test_YZslice(1,1,:,j))
%         ImageToSave = test_YZslice(:,:,k,j);
%         imwrite(ImageToSave,num2str(k),'tiff');
%     end
%     cd(mydir);
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Better framework for saving below
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make the destination directory the same name as the original tiff file and enter.
% mkdir(fname);
% cd(fname);
% % Next, make a figures subdirectory to contain the images and enter
% mkdir('figures');
% cd('figures');
%close all;




%determine total intensity per time point%%
for ww = 1:length(test_YZslice(1,1,1,:))
    for xx = 1:length(test_YZslice(1,1,:,1))
        sum_val(xx) = sum(sum(test_YZslice(:,:,xx,ww)));
    end
    diff_sum_val = diff(sum_val);
    sq_diff_sum_val = (diff_sum_val).^2;
sum_intensity(ww) = sum(sum_val);
sum_sq_diff(ww) = sum(sq_diff_sum_val);
end
figure;plot(sum_intensity)
xlabel('Stack Number')
ylabel('Intensity)')
title('Integrated Intensity (per stack)')
figure;plot(sum_sq_diff)
xlabel('Stack Number')
ylabel('Slice Intensity Difference Squared)')
title('Intensity Difference Squared (per stack)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
%Slice_sum(a) = sum(sum(test_YZslice(:,:,a)))';
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%plotting
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   figure(a);image(YZslice(:,:,a),'CDataMapping','scaled');  %1800 used to scale the data so that it shows up in the [0 1] colormap
%   caxis([0 255])
% %   figure(a);image(YZslice(:,:,a)*1500,'CDataMapping','scaled');  %1800 used to scale the data so that it shows up in the [0 1] colormap
% %   caxis([0 1])
% 
%   %set(gcf,'PaperPositionMode','auto')
%  colormap gray;
%  
%  
%   %save figure to folder
%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   %imwrite(figure(a),'figure(a).tiff');
%   %figure(a+100);surf(YZslice(:,:,a));
%   
%   C(a) = getframe;
%   clear yz;
  

%Determine the intensity weighted centroid for each y-slice in the stack
for t = 1:length(test_YZslice(1,1,1,:))
    for a = 1:length(test_YZslice(1,1,:,1))  
        I = test_YZslice(:,:,a,t);
        bw = I<255;
        bw = imfill(bw,'holes');
        L = bwlabel(bw);
        %imshow(label2rgb(L,@jet, [.7 .7 .7]))
        s = regionprops(L, 'PixelIdxList', 'PixelList');
    
        idx = s(1).PixelIdxList; 
        sum_region1 = sum(I(idx)); 
        x = s(1).PixelList(:, 1); 
        y = s(1).PixelList(:, 2);  
        xbar(a,t) = sum(x .* double(I(idx))) / sum_region1;     %Intensity weighted centroid X
        ybar(a,t) = sum(y .* double(I(idx))) / sum_region1;     %Intensity weighted centroid Y
        colormap(gray);
        figure(a);image(test_YZslice(:,:,a,1),'CDataMapping','scaled');  %1800 used to scale the data so that it shows up in the [0 1] colormap
        caxis([0 255])
        hold on;plot(xbar(a),ybar(a),'*r');
        Gauss_slice = im2double(test_YZslice(:,:,a,t));
        Gauss_slice(isnan(Gauss_slice))=0;
        [ cx,cy,sx,sy,PeakOD ] = Gaussian2D(Gauss_slice,.1);
        gauss_x(a,t) = cx;
        gauss_y(a,t) = cy;
        hold on;plot(gauss_x(a),gauss_y(a),'*')
    end
end
for tp = 1:length(test_YZslice(1,1,1,:))
    figure;plot(gauss_x(:,tp)-mean(gauss_x(:,tp)))
    hold on;plot(gauss_y(:,tp)-mean(gauss_y(:,tp)))
    legend('Centroid X-Locaion','Centroid Y-Location')
    xlabel('Down-the-tube Slice')
end



x_calib = 1;
y_calib = 1;
z_calib = .75;
d = linspace (1,length(test_YZslice(1,1,:,1)),length(test_YZslice(1,1,:,1)));
d_rep = repmat(d',1,length(xbar(1,:)));


% %11/22/2017 comment
% for j =1:50%length(test_YZslice(1,1,1,:))
% figure(100+j);scatter3sph_jkf_edit(xbar(5:end-5,j),ybar(5:end-5,j),d_rep(5:end-5,j),[min(min(xbar(5:end-5))) max(max(xbar(5:end-5)))],[min(min(ybar(5:end-5))) max(max(ybar(5:end-5)))], [min(min(d_rep(5:end-5))) max(max(d_rep(5:end-5)))],'transp',.85, 'size', 2)
% %figure(100+j);scatter3sph(randn(100,1),randn(100,1),randn(100,1),'transp',.85, 'size', .2)
% %o = findobj('type','surface');
% %delete(o);
% %scatter3sph(xbar(10:end-10,j),ybar(10:end-10,j),d_rep(10:end-10,j),'transp',.85, 'size', 2);pause(.1);
% drawnow;
% %grid on;
% q=gcf;
% ax = get(q,'Children');
% % pbaspect manual;
% % daspect manual;
% set(ax,'DataAspectRatioMode','auto')
% set(ax,'PlotBoxAspectRatioMode','auto')
% set(ax,'ActivePositionProperty', 'outerposition')
% % set(ax,'PlotBoxAspectRatioMode','manual');
% % set(ax,'PlotBoxAspectRatioMode','manual');
% set(ax,'NextPlot','replace')
% %set(ax,'mode','manual');
% set(ax,'CameraPositionMode','manual')
% set(ax,'CameraTargetMode','auto')
% set(ax,'CameraUpVectorMode','manual')
% set(ax,'CameraViewAngleMode','manual')
% % set(ax,'XLIM', [-2 2]);
% % set(ax,'YLIM', [-2 2]);
% % set(ax,'ZLIM', [-2 2]);
% % set(ax,'XTickMode','manual')
% % set(ax,'YTickMode','manual')
% % set(ax,'ZTickMode','manual')
% % set(ax,'TickDirMode','manual')
% % set(ax,'TickLabelInterpreter','none')
% % set(ax,'XTickLabelMode','manual')
% % set(ax,'YTickLabelMode','manual')
% % set(ax,'ZTickLabelMode','manual')
% set(ax,'XLIM', [min(min(xbar(5:end-5))) max(max(xbar(5:end-5)))]);
% set(ax,'YLIM', [min(min(ybar(5:end-5))) max(max(ybar(5:end-5)))]);
% set(ax,'ZLIM', [min(min(d_rep(5:end-5))) max(max(d_rep(5:end-5)))]);
% %blah = get(ax,'cameraPosition');
% set(ax,'cameraPosition',[12.5, 33.4, 143.2]);  %instead of view
% set(ax,'cameraUpVector',[0.2, 0, .5]);
% set(ax,'Position',[0.1300    0.1100    0.7750    0.8150]);
% set(ax,'CameraViewAngle', 9)                    %instead of view ->set these in scatter3sph_jkf_edit code
% %view = [-160,-8.5];
% print(figure(100+j), '-dtiff');
% close;
% %saveas(q,'figure_%d.tif',q);
% end
% 
% box_width = 4;
% half_box = box_width/2;
% for ww = 1:length(test_YZslice(1,1,1,:))
%     for xx = 1:length(test_YZslice(1,1,:,1))
%         x_index = round(xbar(xx,ww));
%         y_index = round(ybar(xx,ww));
%         xmin = x_index - half_box;
%         xmax = x_index + half_box;
%         ymin = y_index - half_box;
%         ymax = y_index + half_box;
%         cent_sum_val(xx) = sum(sum(test_YZslice(ymin:ymax,xmin:xmax,xx,ww)));
%     end
%     cent_diff_sum_val = diff(cent_sum_val);
%     cent_sq_diff_sum_val = (cent_diff_sum_val).^2;
% cent_sum_intensity(ww) = sum(cent_sum_val);
% cent_sum_sq_diff(ww) = sum(cent_sq_diff_sum_val);
% end
% figure;plot(cent_sum_intensity)
% xlabel('Stack Number')
% ylabel('Intensity')
% title('ROI Integrated Intensity (per stack)')
% figure;plot(cent_sum_sq_diff)
% xlabel('Stack Number')
% ylabel('Slice Intensity Difference Squared')
% title('ROI Intensity Difference Squared (per stack)')



