function [ test_YZslice, xbar, ybar ] = NucleoidCentroidGaussian(name_tiff_stack, steps_per_tp, start_y, end_y)
%   Function makes end-on images of your 3D slice starting from the top
%   of 2D image. 'wPhase' means there is a circle drawin on the nucleoid
%   data corresponding to the width of the center phase image at that slice 
%           name_tiff_stack = name of file for analysis
%           steps_per_tp = # of z slices in the stack
%           start_y = row (y value) for starting analysis. 1 = imag. top
%           end_y = row (y val) for ending slice analysis. 
%           
%   Program produces garbage before/after nucleoid, so important to cut
%   using start_y and end_y
%
%  Example usage: [ test_YZslice, xbar, ybar ] = NucleoidCentroidGaussian('Slide8_t55_3Dstack_A1.tif', 11, 4, 39);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Read in images from folder
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fname = name_tiff_stack;
info = imfinfo(fname);
num_images = numel(info);
for k = 1:num_images
image_stack(:,:,k) = imread(fname,k);
end

%Determine the total number of time points in file
num_tp = length(image_stack(1,1,:))/steps_per_tp;

%reshape the stack to make individual time points
stack_array = reshape(image_stack,length(image_stack(:,1,1)), length(image_stack(1,:,1)), steps_per_tp, num_tp);
        

%Make Z projections for each time point
for k =1:num_tp
    z_proj(:,:,k) = sum(stack_array(:,:,:,k),3);
end

%Determine location of highest intensity in the Z-projection
[maxval,idx] = max(z_proj(:,:,:),[],2);
y_idx_vals = 1:length(idx)';
spline_y = 0:.5:length(idx)';
%xx = spline(y_idx_vals,idx(:,1,r),spline_y)


% %Plot z projection and indicate pixels of highest intensity (down the tube)
% for r = 1:num_tp
%     figure;imagesc(z_proj(:,:,r))
%     colormap(hot);
%     xx = spline(y_idx_vals,idx(:,1,r),spline_y);
%     smooth_x = smooth(idx(:,1,r),5);
%     hold on;plot(idx(:,1,r),y_idx_vals,'*')
%     %hold on;plot(xx,spline_y,'r','LineWidth',5)
%     hold on;plot(smooth_x,y_idx_vals,'b','LineWidth',4);
% end




%%Make YZ slices
for t = 1:length(stack_array(1,1,1,:))
    for a = 1:length(stack_array(:,1,1,1))
        xz(:,:,a,t) = squeeze(stack_array(a,:,:,t)); %but xz needs to be xz'
    end
end
test_YZslice = xz(:,:,start_y:end_y,:);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Code below can be used to save YZ slices from each timepoint
% Not a great way to do it (code is garbage)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mydir = pwd;
% for j = 1:length(test_YZslice(1,1,1,:))
%     new_dir = mkdir(num2str(j));
%     save_dir = strcat(mydir,'/',num2str(new_dir));
%     cd(save_dir);
%     for k = 3:length(test_YZslice(1,1,:,j))
%         ImageToSave = test_YZslice(:,:,k,j);
%         imwrite(ImageToSave,num2str(k),'tiff');
%     end
%     cd(mydir);
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Better framework for saving below
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make the destination directory the same name as the original tiff file and enter.
% mkdir(fname);
% cd(fname);
% % Next, make a figures subdirectory to contain the images and enter
% mkdir('figures');
% cd('figures');
%close all;




% %determine total intensity per time point%%
% for ww = 1:length(test_YZslice(1,1,1,:))
%     for xx = 1:length(test_YZslice(1,1,:,1))
%         sum_val(xx) = sum(sum(test_YZslice(:,:,xx,ww)));
%     end
%     diff_sum_val = diff(sum_val);
%     sq_diff_sum_val = (diff_sum_val).^2;
% sum_intensity(ww) = sum(sum_val);
% sum_sq_diff(ww) = sum(sq_diff_sum_val);
% end
% figure;plot(sum_intensity)
% xlabel('Stack Number')
% ylabel('Intensity)')
% title('Integrated Intensity (per stack)')
% figure;plot(sum_sq_diff)
% xlabel('Stack Number')
% ylabel('Slice Intensity Difference Squared)')
% title('Intensity Difference Squared (per stack)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
%Slice_sum(a) = sum(sum(test_YZslice(:,:,a)))';
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%plotting
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   figure(a);image(YZslice(:,:,a),'CDataMapping','scaled');  %1800 used to scale the data so that it shows up in the [0 1] colormap
%   caxis([0 255])
% %   figure(a);image(YZslice(:,:,a)*1500,'CDataMapping','scaled');  %1800 used to scale the data so that it shows up in the [0 1] colormap
% %   caxis([0 1])
% 
%   %set(gcf,'PaperPositionMode','auto')
%  colormap gray;
%  
%  
%   %save figure to folder
%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   %imwrite(figure(a),'figure(a).tiff');
%   %figure(a+100);surf(YZslice(:,:,a));
%   
%   C(a) = getframe;
%   clear yz;
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Methods for plotting "brightest" pixels below.
% Intensity weighted centroid (red) as well as gaussian fit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for t = 1:length(test_YZslice(1,1,1,:))
    for a = 1:length(test_YZslice(1,1,:,1))  
        I = test_YZslice(:,:,a,t);
        bw = I<255;
        bw = imfill(bw,'holes');
        L = bwlabel(bw);
        %imshow(label2rgb(L,@jet, [.7 .7 .7]))
        s = regionprops(L, 'PixelIdxList', 'PixelList');
        idx = s(1).PixelIdxList; 
        sum_region1 = sum(I(idx)); 
        x = s(1).PixelList(:, 1); 
        y = s(1).PixelList(:, 2);  
        xbar(a,t) = sum(x .* double(I(idx))) / sum_region1;     %Intensity weighted centroid X
        ybar(a,t) = sum(y .* double(I(idx))) / sum_region1;     %Intensity weighted centroid Y
        colormap(gray);
        figure(a);image(test_YZslice(:,:,a,1),'CDataMapping','scaled');  %1800 used to scale the data so that it shows up in the [0 1] colormap
        caxis([0 255])
        hold on;plot(xbar(a),ybar(a),'*r');
        Gauss_slice = im2double(test_YZslice(:,:,a,t));
        Gauss_slice(isnan(Gauss_slice))=0;
        [ cx,cy,sx,sy,PeakOD ] = Gaussian2D(Gauss_slice,.1);
        gauss_x(a,t) = cx;
        gauss_y(a,t) = cy;
        hold on;plot(gauss_x(a),gauss_y(a),'*')
    end
end

% Plot location of center of gaussian for all down the tube slices 
for tp = 1:length(test_YZslice(1,1,1,:))
    figure;plot(gauss_x(:,tp)-mean(gauss_x(:,tp)))
    hold on;plot(gauss_y(:,tp)-mean(gauss_y(:,tp)))
    legend('Centroid X-Locaion','Centroid Y-Location')
    xlabel('Down-the-tube Slice')
end
