% FinalImage = TiffLoad_partial_multi(name, pathtofile, im_info, color, time)
% Extracts from an experiment a stack of a specific "color" at a specific
% "time" for a file of a specific name
%
% Inputs:   name :          name of the file (without "tiff)
%           pathtofile :    path to the folder containing the file
%           im_info :       im_info structure
%           color :         color # to be extracted 
%           time :          time point to be extracted. If time is [], the
%                           whole time series is extracted by combining
%                           all planes of all time points of color into
%                           FinalImage
%  
% Output:   FinalImage:  stack of images
%               

function FinalImage = TiffLoad_partial_multi(name, pathtofile, im_info, color, time)

oldfolder=cd(pathtofile);

image_set=[im_info.indices{color,1}];
nplans = im_info.nbPlanes(color);

if isempty(time)
    FinalImage=zeros(im_info.height_or,im_info.width_or,size(im_info.times,1)*nplans,'uint16');
    
    for t=1:size(im_info.times,1)
        filename = strcat(name,'_T',num2str(im_info.times(t)),'.tiff');
        
        FileTif=filename;
        TifLink = Tiff(FileTif, 'r');
        TifLink.setDirectory(1);
        
        for nbim=1:nplans
            TifLink.setDirectory(image_set(nbim));
            FinalImage(:,:,(t-1)*nplans+nbim)=TifLink.read();
        end
        TifLink.close();
    end
    
else
    FinalImage=zeros(im_info.height_or,im_info.width_or,nplans,'uint16');
    filename = strcat(name,'_T',num2str(time),'.tiff');
    FileTif=filename;
    TifLink = Tiff(FileTif, 'r');
    TifLink.setDirectory(1);
    
    for nbim=1:nplans
        TifLink.setDirectory(image_set(nbim));
        FinalImage(:,:,nbim)=TifLink.read();
    end
    TifLink.close();
end


cd(oldfolder)

end

    
    
    
    
    
    
    
    
    
    
    
    
    
    
    