%Multi-color, 3D, time-lapse acquisition on a grid.

%----------------------------------------------------------
%----------------------------------------------------------
%Parameters to be defined by user:

%Colors to take
% colors={'phase', 'mcherry', 'FITC'};
% colors={'phase','mcherry','mteal','mvenus'};
% colors={'phase','mcherry','mteal'};
% colors={'phase','mteal','mcherry_PA'};
colors={'phase','mcherry','mvenus','mteal'};
%Add details about each color. Choices: phase, wall, nucleoid,spot. Leave
%as {'none'} in case not used.
% type = {'phase', 'nucleoid', 'spot', 'spot'};
type = {'phase', 'nucleoid','spot','spot'};
% type = {'phase','nucleoid','nucleoid'};
% type = {'phase', 'nucleoid', 'spot', 'spot'};
biology = {'phase', 'hupA-mCherry','lacO-asnA','tetO-ter'};
% biology = {'phase', 'hupA-mCherry','lacO-asnA'};
% biology = {'phase','hupA-mCherry','lacO-asnA','tetO-lac'};
% biology = {'phase','hupA-TFP','hupA-PAmCherry'};
%Number of planes for each color
% planes={1,9,9,9};
planes={33,11,11,3};
% planes={33,3,3};
%Periodicity at which a color is taken
color_period={1,1,1,1};
% color_period={1,1,1};
%Z-step for stack acquisition
zstep=0.2;%microns
%Generic name of files
to_save_name = 'GW242';
%Place where to save
pathtofile = 'J:\Mathieu\2015\';
%Number of grid points to scan
gridx=size(selected,1);
gridy=1;
%Grid size
gridsize=40;%microns
%Number of times the grid is scanned.
nbtime=2;
%Time to wait between starting times of grid points acquistion. If timestep 
%is shorter than the actual times one grid point acquisition takes, the
%scope goes as fast as possible
% timestep=20; %in seconds
timestep=20;
%Should the first acquisition point be without fluorescence as a control?
neg_control=1;

%Add a comment about your data
comment  = 'GW246 grown in AB with antibio. Took 200ul and mixed with fm4-64 final 1uM, and spotted on AB pad.';
%Camera properties
magnification = magn;
pixelsize = physpix;
%----------------------------------------------------------
%----------------------------------------------------------

mainplot=figure(); figure(mainplot)
imshow(largeim2,[]); hold on
for i=1:size(allx,1)
    plot(allx(i,:),ally(i,:));
end
hold off;

print(mainplot,'-djpeg','-r600',strcat(pathtofile,'/gridplot_start.jpg'))
% print(mainplot,'-djpeg','-r600',strcat(pathtofile,'/gridplot_end.jpg'))
close all
pause(0.5)

%Set grid origin at current location
% mmc.setOriginXY('XYStage');
% mmc.waitForDevice('XYStage');

%Initialize time counters
nbtimecount=1;
timecount=0;
timefirstcount=0;
timegrid=zeros(size(selected,1),1);
gridx = size(selected,1);gridy=1;

%Variables initialization
totplanes=sum(cat(1,planes{:}),1);
mastertimes=cell(1,totplanes);
nbcolors = length(colors);
nbpixels=cam_nbpix;
NA=1.4;


%Setting up header information
clear headerGW;
headerGW.nbcolors={nbcolors};
headerGW.colors=colors;
headerGW.planes=planes;
headerGW.color_period=color_period;
headerGW.zstep={zstep};
headerGW.nbpixels={nbpixels};
headerGW.gridx={gridx};
headerGW.gridy={gridy};
headerGW.timestep={timestep};
headerGW.nbtime={nbtime};
headerGW.gridposx={0};
headerGW.gridposy={0};
headerGW.iteration={nbtimecount};

copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Grid_acquisition\aquisition_picked.m',pathtofile)
for i=1:nbcolors
    if(strcmp(colors{i},'phase')==1)
        setting_phase;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_phase.m',pathtofile)
    elseif(strcmp(colors{i},'mcherry')==1)
        setting_mcherry;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_mcherry.m',pathtofile)
    elseif(strcmp(colors{i},'mcherry_PA')==1)
        setting_mcherry_PA;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_mcherry_PA.m',pathtofile)
    elseif(strcmp(colors{i},'mcherry_intense')==1)
        setting_mcherry_pointsel;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_mcherry_pointsel.m',pathtofile)
    elseif (strcmp(colors{i},'mvenus')==1)
        setting_mVenus;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_mVenus.m',pathtofile)
    elseif (strcmp(colors{i},'FITC')==1)
        setting_FITC;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_FITC.m',pathtofile)
    elseif (strcmp(colors{i},'mteal')==1)
        setting_mTeal;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_mTeal.m',pathtofile)
    elseif (strcmp(colors{i},'cy5')==1)
        setting_cy5;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_cy5.m',pathtofile)
    elseif (strcmp(colors{i},'empty')==1)
        setting_empty;
        copyfile('C:\Users\gwitz\Desktop\Nikon\Required\Settings_coli\setting_empty.m',pathtofile)
    end
    mmc.setProperty('Spectra', 'White_Level', 0);
    if strcmp(camsel,'EMCCD')
        gain{i} = str2num(mmc.getProperty('HamamatsuEMCCD', 'Gain'));
        emgain{i} = str2num(mmc.getProperty('HamamatsuEMCCD', 'EMGain'));
    else
        gain{i} = 0;
        emgain{i} = 0;
    end
    expos{i} = exposure;
    lev_col{i} = level;
end
headerGW.gain = gain;
headerGW.emgain = emgain;
headerGW.exposure = expos;
headerGW.level = lev_col;
headerGW.comment = {comment};
headerGW.type = type;
headerGW.biology = biology;
headerGW.magnification = {magnification};
headerGW.pixelsize = {pixelsize};
headerGW.NA = {NA};


%----------------------------------------------------------
%----------------------------------------------------------
%Start data acquisition
% nbtimecount=36;

t1=clock();
masterclock=clock();
while nbtimecount<=nbtime
    for g1=1:size(selected,1)
        
%         tic
        strcat('Point: ',num2str(g1), ', Time: ', num2str(nbtimecount))
        
        %Move to desired point
        mmc.setXYPosition('XYStage',-selected(g1,1),-selected(g1,2))
        mmc.waitForDevice('XYStage');
        
        %Make sur PFS is locked after stage move
        mmc.enableContinuousFocus(1);
        mmc.waitForDevice('TIPFSStatus');
        pfscurstatus=strcmp(mmc.getProperty('TIPFSStatus','Status'),'Locked in focus');
        while pfscurstatus==0
            pfscurstatus=strcmp(mmc.getProperty('TIPFSStatus','Status'),'Locked in focus');
        end
        %Set piezo to middle range
        mmc.setPosition('DA Z Stage',50);
        mmc.waitForDevice('DA Z Stage');
        
        
        %Set up a matrix to store the data
        imtot=zeros(nbpixels*nbpixels,totplanes, 'uint16');
        
        %Start the clock
        t2=clock();
        diff=etime(t2,t1);
        %If this is the first time point of the first grid point, start
        %directly
        if timefirstcount==0
            diff=timestep;
            timefirstcount=1;
        end
        
        %Wait until timestep passed since the last XY position.
        while diff<timestep
            t2=clock();
            diff=etime(t2,t1);
        end
        %Once found re-start the clock for next point
        t1=clock();
        
        %TAKE THE ACTUAL DATA
        mmc.enableContinuousFocus(0);
        mmc.waitForDevice('TIPFSStatus');
        planecount=1;%counts planes to accumulate in imtot
        for col=1:nbcolors
            if (strcmp(colors{col},'phase')==1)
                setting_phase;
                mmc.setProperty('TIDiaShutter','State',1);
                mmc.waitForDevice('TIDiaShutter');
                for pl=1:planes{col}
                    
                    mmc.setPosition('DA Z Stage',50-zstep*(planes{col}+1)/2+pl*zstep);
                    mmc.waitForDevice('DA Z Stage');
                    masterclock2=clock();
                    diff=etime(masterclock2,masterclock);
                    mastertimes{planecount}=diff;
                    mmc.snapImage();
                    snapped=mmc.getImage();
                    imtot(:,planecount) = typecast(snapped,'uint16');
                    planecount=planecount+1;
                end
                mmc.setProperty('TIDiaShutter','State',0);
                mmc.waitForDevice('TIDiaShutter');
                mmc.setPosition('DA Z Stage',50);
                mmc.waitForDevice('DA Z Stage');
                
                %Empty camera 'memory' by taking a frame with no light
                mmc.snapImage();
                snapped=mmc.getImage();
                
            else
                if(strcmp(colors{col},'mcherry')==1)
                    setting_mcherry;
                elseif(strcmp(colors{col},'mcherry_PA')==1)
                    setting_mcherry_PA;
                elseif (strcmp(colors{col},'mvenus')==1)
                    setting_mVenus;
                elseif (strcmp(colors{col},'mcherry_intense')==1)
                    setting_mcherry_pointsel;
                elseif (strcmp(colors{col},'FITC')==1)
                    setting_FITC;
                elseif (strcmp(colors{col},'mteal')==1)
                    setting_mTeal;
                elseif (strcmp(colors{col},'cy5')==1)
                    setting_cy5;
                end
                
                %The first point in the series has no fluorescence as
                %control. Also check for periodicity
                if neg_control==1
                    if g1==1
                        mmc.setProperty('Spectra', 'White_Level', 0);
                    end
                end
                if mod(nbtimecount-1,color_period{col})~=0
                    mmc.setProperty('Spectra', 'White_Level', 0);
                end
                
                %All specical modifications go here
                %Turn off blue light on second point 
%                 if g1==2
%                     if (strcmp(colors{col},'mteal')==1)
%                         mmc.setProperty('Spectra', 'White_Level', 0);
%                     end
%                 end
                
               
                
%                 %Take first an image that isn't stored because of Flash
%                 %camera issue
%                 mmc.snapImage();
%                 snapped=mmc.getImage();
                    
                for i=1:planes{col}
                    mmc.setPosition('DA Z Stage',50-zstep*(planes{col}+1)/2+i*zstep)
                    mmc.waitForDevice('DA Z Stage');
                    masterclock2=clock();
                    diff=etime(masterclock2,masterclock);
                    mastertimes{planecount}=diff;
                    mmc.snapImage();
                    snapped=mmc.getImage();
                    imtot(:,planecount) = typecast(snapped,'uint16');
                    planecount=planecount+1;
                end
                %Put everything back in order before next color
                mmc.setProperty('Spectra', 'White_Level', 0);
                mmc.setPosition('DA Z Stage',50);
                mmc.waitForDevice('DA Z Stage');
            end
        end
        
        strcat('Finished acquisition: ',num2str(g1))
        
%         name=strcat(to_save_name,'_X',num2str(g1),'.tiff');
        name=strcat(to_save_name,'_X',num2str(g1),'_T',num2str(nbtimecount),'.tiff');
        headerGW.gridposx={g1};
        headerGW.gridposy={1};
        headerGW.iteration={nbtimecount};
        headerGW.mastertimes=mastertimes;
        
        reshaped = reshape(imtot,nbpixels,nbpixels,totplanes);
        for i=1:totplanes
            reshaped(:,:,i) = reshaped(:,:,i)';
        end
        
        im_description =metadataGW(headerGW, name);
        imwrite(reshaped(:,:,1),  strcat(pathtofile,'/',name), 'Description',im_description);
        
        for imdimz=2:totplanes
            imwrite(reshaped(:,:,imdimz), strcat(pathtofile,'/',name), 'WriteMode', 'append');
        end
        
%         if timegrid(g1,1)==0
%             createTiffGW(name, reshaped,headerGW, pathtofile);
%         else
%             fillTiffGW(name,reshaped, headerGW, pathtofile);
%         end
%         timegrid(g1,1)=1;
        
%         strcat('Finished writing: ',num2str(g1))
%        toc 
    end
    
    nbtimecount=nbtimecount+1;
end








