function metadata = kvpairs2struct(kvpairs)
   kv_delimiter = ':';
   val_delimiter = ',';
   
% initialize metadata structure
   metadata = struct;
   
   % for every key-value pair
   for k = 1:length(kvpairs)
       
       mykvpair = kvpairs{k};
       
       % check for presence of key-value delimiter character, usually a ':'
       if regexp(mykvpair, kv_delimiter)
           
           delimiter_location = regexp(mykvpair, kv_delimiter);
                     
           % extract key name
           key = strtrim(mykvpair(1:delimiter_location-1));
           
           val = strtrim(mykvpair(delimiter_location+1:end-1));
           
           % some vals are text strings while others are numeric. We'll
           % have to determine which is which by using yet another
           % delimiter, usually the ','.
           val_delimiter_locations = regexp(val, val_delimiter);
           num_subvals = length(val_delimiter_locations)+1;
           
           % for every 'subvalue' found within the value of the key-value pair
           for m = 1:num_subvals
               if m==1
                   starting_location = 1;
               else
                   starting_location = 1+val_delimiter_locations(m-1);
               end

               if m==num_subvals
                   ending_location = length(val);
               else
                   ending_location = val_delimiter_locations(m);
               end
       
               % extract and clean the subvalue
               subval = val(starting_location:ending_location);
               subval = strrep(subval, val_delimiter, '');
               subval = strtrim(subval);
                                             
               % try converting the subval to a number- failing to do so
               % results in an empty matrix
               mynumtest =  str2num(subval);
               
               % if we get empty matrix, it's a string, if not, it's a
               % number
               if ~isempty(mynumtest)
                   newval(m) = mynumtest;
               else
                   newval{m} = subval;
               end                                                 
           end
           
           % insert new field into the output metadata structure
           metadata = setfield(metadata, key, newval);          
           
           % clear the new val in case the next one is of a different type
           % (i.e. a string instead of a number or vice-versa)
           clear newval;
       end
   end
   
   return;