% MODEL_VOLUME Script that generates and saves test datasets
%
% Script for the nucleoid analysis that generates test/model/practice
% datasets for the algorithm used here. 
%
% TODO: 
%   - Add ability to include noise in the simulated stacks.
%

N = 6.0;
x=linspace(-N, N, 200);
y=x;
z=x;

sdx = 0.5;
sdy = 0.5;
sdz = 1;

[X,Y,Z]=meshgrid(x,y,z);

clear uvw uvwSpiral


% y-shifted
w = (1000/sqrt(2*pi).*exp(-(3*(X+1.5).^2/(2*sdx^2))-(0.7*(Y-1).^2/(2*sdy^2))-(8*Z.^2/(2*sdz^2))));
w = (w-min(w(:)))/(max(w(:))-min(w(:))) * 256;

v = zeros(size(w));
v = (1000/sqrt(2*pi).*exp(-(0.3*X.^2/(2*sdx^2)) - (4*(Y+2).^2/(2*sdy^2)) - (3*(Z-0.5).^2/(2*sdz^2))));
v = (v-min(v(:)))/(max(v(:))-min(v(:))) * 128;

u = zeros(size(w));
u = (1000/sqrt(2*pi).*exp(-(1*(X-1).^2/(2*sdx^2)) - (1*(Y-1).^2/(2*sdy^2)) - (1*(Z+0.5).^2/(2*sdz^2))));
u = (u-min(u(:)))/(max(u(:))-min(u(:))) * 192;

uvw = u + v + w;
uvw = (uvw-min(uvw(:)))/(max(uvw(:))-min(uvw(:)));

stack_height = size(uvw,3);


[X,Y]=meshgrid(x,y);
% myG2d = (1000/sqrt(2*pi).*exp(-(3*(X).^2/(2*sdx^2))-(0.7*(Y).^2/(2*sdy^2))));
myG2d = (1000/sqrt(2*pi).*exp(-((X-sdx/2).^2/(2*sdx^2))-((Y-sdy/2).^2/(2*sdy^2))));
myG2d = myG2d/(max(myG2d(:)));

sdz = 1.75;
taperZ = 1/(sdz*sqrt(2*pi)) .* exp(-(1/2)*( (z-0)/sdz ).^2);
taperZ = taperZ/max(taperZ(:));

% poof = figure;
for tw = 1:stack_height
    im = myG2d;
    rrr = imrotate(im, tw*(4*360)/stack_height,'bilinear','crop');
    uvwSpiral(:,:,tw) = taperZ(tw) .* rrr;
    tendril(:,:,tw) = rrr;
%     figure(poof); imagesc(rrr); drawnow;
end
% close(poof);

tendril_perv = cat(3, tendril, flip(tendril,3));
tendrilz=linspace(-2*N, 2*N, 400);
sdtendrilz = 2.25;
tapertendril = 1/(sdtendrilz*sqrt(2*pi)) .* exp(-(1/2)*( (tendrilz-0)./sdtendrilz ).^2);
tapertendril = tapertendril/max(tapertendril(:));
tapertendril = tapertendril(:);
tapertendril = repmat(tapertendril,1,200,200);
tapertendril = permute(tapertendril, [3 2 1]);
tendril_perv = tendril_perv .* tapertendril;
tendril_perv = tendril_perv(:,:,1:2:end);

w = w(50:149,50:149,50:149);
v = v(50:149,50:149,50:149);
u = u(50:149,50:149,50:149);

uvw = uvw(50:149,50:149,50:149);
imwrite(squeeze(uvw(:,:,1)), 'test_gauss_3d.tif');
for k=2:size(uvw,3)  
    imwrite(squeeze(uvw(:,:,k)), 'test_gauss_3d.tif', 'WriteMode', 'append');
end

uvwSpiral_x = permute(uvwSpiral, [1 3 2]);
imwrite(squeeze(uvwSpiral_x(:,:,1)), 'twisted_gauss_3dx.tif');
for k=2:size(uvwSpiral_x,3)  
    imwrite(squeeze(uvwSpiral_x(:,:,k)), 'twisted_gauss_3dx.tif', 'WriteMode', 'append');
end

uvwSpiral_y = permute(uvwSpiral, [3 2 1]);
imwrite(squeeze(uvwSpiral_y(:,:,1)), 'twisted_gauss_3dy.tif');
for k=2:size(uvwSpiral_y,3)  
    imwrite(squeeze(uvwSpiral_y(:,:,k)), 'twisted_gauss_3dy.tif', 'WriteMode', 'append');
end

imwrite(squeeze(uvwSpiral(:,:,1)), 'twisted_gauss_3dz.tif');
for k=2:size(uvwSpiral,3)  
    imwrite(squeeze(uvwSpiral(:,:,k)), 'twisted_gauss_3dz.tif', 'WriteMode', 'append');
end

tendril_perv_x = permute(tendril_perv, [1 3 2]);
imwrite(squeeze(tendril_perv_x(:,:,1)), 'tendril_3dx.tif');
for k=2:size(tendril_perv_x,3)  
    imwrite(squeeze(tendril_perv_x(:,:,k)), 'tendril_3dx.tif', 'WriteMode', 'append');
end

tendril_perv_y = permute(tendril_perv, [3 2 1]);
imwrite(squeeze(tendril_perv_y(:,:,1)), 'tendril_3dy.tif');
for k=2:size(tendril_perv_y,3)  
    imwrite(squeeze(tendril_perv_y(:,:,k)), 'tendril_3dy.tif', 'WriteMode', 'append');
end

imwrite(squeeze(tendril_perv(:,:,1)), 'tendril_3dz.tif');
for k=2:size(tendril_perv,3)  
    imwrite(squeeze(tendril_perv(:,:,k)), 'tendril_3dz.tif', 'WriteMode', 'append');
end


% imwrite(
V = 0;
