function h = play_stack(stack, fps, scanaxis, closeyn)
% PLAY_STACK visualizes a stack by playing through it like a video
%
% h = play_stack(stack, fps, scanaxis, closeyn)
% 
% stack = NxMxP matrix containing luminanace information
% fps = frames per second to play the stack, default = 20
% scanaxis = axis to "play" the video through, i.e. 'X' | {'Y'} | 'Z'
% closeyn = close the figure after playing?  {'y'} | 'n'
% h = handle to output figure
%

if nargin < 4 || isempty(closeyn)
    closeyn = 'y';
end

if nargin < 3 || isempty(scanaxis)
    scanaxis = 'z';
end

if nargin < 2 || isempty(fps)
    fps = 20;
end

if nargin < 1 || isempty(stack)
    error('No stack to display.')
end

delay = 1/fps;
scanaxis = upper(scanaxis);

stack = rot_scanaxis(stack, [], scanaxis, 'scan');

K = size(stack,3);

h = figure; 

stack = scale_stack(stack, 'uint16');

for k = 1:K
    image(squeeze(stack(:,:,k))); 
    colormap(gray(65535)); 
    pause(delay); 
end

if closeyn
    close(h);
    h = [];
end

