function h = plot_centroidproj(nucleoid, projplane)
% PLOT_CENTROIDPROJ plots projections through image stack
%
% h = plot_centroidproj(nucleoid, projplane)
%
% nucleoid = nucleoid stucture outputted by nucleoid_centroid
% projplane = plane onto which to plot the remaining axes, e.g. selecting 'Y'
%             plots X vs Z onto the Y plane. Defaults to value of 'scanaxis'
%             defined in the nucleoid structure. 
% h = handle to plotted figure
%

    if nargin < 2 || isempty(projplane)
        projplane = nucleoid.scanaxis;
    end

    projplane = upper(projplane);
    
    xyzscales = nucleoid.ScalesXYZ;
    [xs, ys, zs] = deal(xyzscales(1), xyzscales(2), xyzscales(3));

    switch projplane
        case 'X'
            X = nucleoid.Cents.Y * ys;
            Y = nucleoid.Cents.Z * zs;
            Z = nucleoid.Cents.X * xs;
        case 'Y'
            X = nucleoid.Cents.X * xs;        
            Y = nucleoid.Cents.Z * zs;
            Z = nucleoid.Cents.Y * ys;
        case 'Z'
            X = nucleoid.Cents.Y * ys;
            Y = nucleoid.Cents.X * xs;
            Z = nucleoid.Cents.Z * zs;
    end

    objlist = unique(nucleoid.Cents.ObjID); 
    Nobj = length(objlist); 

    
    h = figure;

    for k = 1:Nobj
        
        idx = (nucleoid.Cents.ObjID == objlist(k));
        switch projplane
            case 'X'
                xpoints = Z(idx);
                ypoints = Y(idx);
                xl = 'Y [\mum]';
                yl = 'Z [\mum]';
                figtitle = 'X projection';
            case 'Y'
                xpoints = Z(idx);
                ypoints = X(idx);
                xl = 'X [\mum]';
                yl = 'Z [\mum]';
                figtitle = 'Y projection';
            case 'Z'
                xpoints = X(idx);
                ypoints = Y(idx);                
                xl = 'X [\mum]';
                yl = 'Y [\mum]';
                figtitle = 'Z projection';
            otherwise
                error('X, Y, or Z only');
        end

        hand = nucleoid.Cents.Handed(idx);
        
        figure(h); 
        hold on; 
        plot(xpoints, ypoints, 'k-');
        plot(xpoints(hand<0), ypoints(hand<0), 'r.'); 
        plot(xpoints(hand>0), ypoints(hand>0), 'b.'); 
        xlabel(xl);
        ylabel(yl);
        title(figtitle);
        hold off; 

    end
    
    
