function h = plot_centroids3d(nucleoid)
% PLOT_CENTROIDS3D plots a nucleoid isovolume with centroid data
%
% h = plot_centroid3d(nucleoid)
%
% nucleoid = structure outputted by nucleoid_centroid
% h = handle to outputted figure
%

%     if nargin < 2 || isempty(h)
%         h = figure;
%     end

    ObjIDs = unique(nucleoid.Cents.ObjID);
    nObj = length(ObjIDs);

    xyzscales = nucleoid.ScalesXYZ;
    
%     [~,xyzscales] = rot_scanaxis(nucleoid.OrigStack, xyzscales, ...
%                                  nucleoid.ScanAxis, 'scan');
    
    [xs, ys, zs] = deal(xyzscales(1), xyzscales(2), xyzscales(3));
    
    h = plot_isovolume(nucleoid.SegStack, [], xyzscales, true);

    figure(h);
    hold on;     
    
    for k = 1:nObj
        centIDX = nucleoid.Cents.ObjID == ObjIDs(k);
        centX   = nucleoid.Cents.X( centIDX );
        centY   = nucleoid.Cents.Y( centIDX );
        centZ   = nucleoid.Cents.Z( centIDX );
        
        this_hand = nucleoid.Cents.Handed( centIDX );

        plot3( centX.*xs,                centY.*ys,                centZ.*zs, 'k-');
        plot3( centX(this_hand < 0).*xs, centY(this_hand < 0).*ys, centZ(this_hand < 0).*zs, 'r.', 'MarkerSize', 20);
        plot3( centX(this_hand > 0).*xs, centY(this_hand > 0).*ys, centZ(this_hand > 0).*zs, 'b.', 'MarkerSize', 20);
    end

    xlabel('X');
    ylabel('Y');
    zlabel('Z');

    grid on;

    hold off;

%     xlim([0 size(nucleoid.stack,1)]); 
%     ylim([0 size(nucleoid.stack,2)]); 
%     zlim([0 size(nucleoid.stack,3)]);

%         axis square;
    camproj('orthographic');
    cameratoolbar('SetMode', 'orbit');

return
