function h = plot_downthetube(nucleoid, slicenum, uiTF)

    if nargin < 3 || isempty(uiTF)
        uiTF = false;
    end

    if nargin < 2 || isempty(slicenum)
        slicenum = 1;
    end

    if nargin < 1 || isempty(nucleoid)
        error('No data to plot.');
    end

    scanaxis = upper(nucleoid.ScanAxis);

    origstack   = nucleoid.OrigStack;
    scaledstack = scale_stack(nucleoid.OrigStack, 'uint8');
    segstack = scale_stack(nucleoid.SegStack, 'uint8');
    objstack = scale_stack(nucleoid.ObjIdStack, 'uint8');

    origstack   = rot_scanaxis(origstack, [], scanaxis, 'scan');
    scaledstack = rot_scanaxis(scaledstack, [], scanaxis, 'scan');
    segstack = rot_scanaxis(segstack, [], scanaxis, 'scan');
    objstack = rot_scanaxis(objstack, [], scanaxis, 'scan');

    objIDs    = nucleoid.Cents.ObjID;
    XYZcentroid = [nucleoid.Cents.X nucleoid.Cents.Y nucleoid.Cents.Z];
    
    
    K = size(scaledstack,3);
        
    % Need to get the output coordinates back in the lab frame. These will
    % depend on the plane used for the centroids
    switch scanaxis
        case 'X'
            XYZcentroid(:,[1 2 3]) = XYZcentroid(:,[3 2 1]);
        case 'Y'
            XYZcentroid(:,[1 2 3]) = XYZcentroid(:,[1 3 2]);
        case 'Z'
            % nothing needs to change
        otherwise
            % given earlier switch, this should never happen
    end

    h = figure;
    
    %%% NEED A SLICE CHECK IF NO UI
    
    k = slicenum;

    origframe   = squeeze(origstack(:,:,k));
    scaled_frame = squeeze(scaledstack(:,:,k));
    segframe    = squeeze(segstack(:,:,k));
    objframe    = squeeze(objstack(:,:,k));
        
%          fprintf('frame=%u, max(origframe)= %u, max(scaledframe)= %u, max(segframe)= %u, max(objframe)= %u\n', ...
%                   k, max(double(origframe(:))), max(double(scaled_frame(:))), max(double(segframe(:))), max(double(objframe(:))));
    
%         objs_in_frame = Mcentroid( Mcentroid(:,4) == k );
        
    cent = XYZcentroid( XYZcentroid(:,3) == k, 1:2);
    id = unique(objIDs( XYZcentroid(:,3) == k ));

    nudgeX = size(origframe,2) * 0.05;
    nudgeY = size(origframe,1) * 0.05;

      subplot(1,3,1);
      image(scaled_frame);
      colormap(gray(256));
      title(['orig, scanaxis:' scanaxis]);
      axis square;

      subplot(1,3,2);
      image(segframe);
      colormap(gray(256));
      title('segmented');
      axis square;

      subplot(1,3,3);
      imagesc(objframe);
      colormap(gray(256));
      hold on;
          plot(cent(:,1), cent(:,2), 'og');
          text(cent(:,1) + nudgeX, cent(:,2) + nudgeY, num2str(id), 'Color', 'green');
      hold off;
      title('centroid');
      axis square;

      drawnow;
    
    h = 0;

return