function plot_nucleoid_centroid(nucleoid, fps, videoyn, videoname)
% PLOT_NUCLEOID_CENTROID plays the nucleoid volume and centroids as a video sequence
%
% plot_nucleoid_centroid(nucleoid, fps, videoyn, videoname)
%
% nucleoid = structure outputted by nucleoid_centroid
% fps = frames per second to play the stack, default = 20
% videoyn = save the video as an avi? 'y' | {'n'}
% videoname = output .avi filename for video
%

if nargin < 4 || isempty(videoname)
    videoname = 'myfile.avi';
end

if nargin < 3 || isempty(videoyn)
    videoyn = 'n';
end

if nargin < 2 || isempty(fps)
    fps = 20;
end

    scanaxis = upper(nucleoid.ScanAxis);

    origstack   = nucleoid.OrigStack;
    scaledstack = scale_stack(nucleoid.OrigStack, 'uint8');
    segstack = scale_stack(nucleoid.SegStack, 'uint8');
    objstack = scale_stack(nucleoid.ObjIdStack, 'uint8');

    origstack   = rot_scanaxis(origstack, [], scanaxis, 'scan');
    scaledstack = rot_scanaxis(scaledstack, [], scanaxis, 'scan');
    segstack = rot_scanaxis(segstack, [], scanaxis, 'scan');
    objstack = rot_scanaxis(objstack, [], scanaxis, 'scan');

    objIDs    = nucleoid.Cents.ObjID;
    XYZcentroid = [nucleoid.Cents.X nucleoid.Cents.Y nucleoid.Cents.Z];
    
    
    K = size(scaledstack,3);
        
    % Need to get the output coordinates back in the lab frame. These will
    % depend on the plane used for the centroids
    switch scanaxis
        case 'X'
            XYZcentroid(:,[1 2 3]) = XYZcentroid(:,[3 2 1]);
        case 'Y'
            XYZcentroid(:,[1 2 3]) = XYZcentroid(:,[1 3 2]);
        case 'Z'
            % nothing needs to change
        otherwise
            % given earlier switch, this should never happen
    end

    h = figure;
    
    for k=1:K   % iterate through the frames
        
        origframe   = squeeze(origstack(:,:,k));
        scaled_frame = squeeze(scaledstack(:,:,k));
        segframe    = squeeze(segstack(:,:,k));
        objframe    = squeeze(objstack(:,:,k));
        
%          fprintf('frame=%u, max(origframe)= %u, max(scaledframe)= %u, max(segframe)= %u, max(objframe)= %u\n', ...
%                   k, max(double(origframe(:))), max(double(scaled_frame(:))), max(double(segframe(:))), max(double(objframe(:))));
    
%         objs_in_frame = Mcentroid( Mcentroid(:,4) == k );
        
          cent = XYZcentroid( XYZcentroid(:,3) == k, 1:2);
          id = unique(objIDs( XYZcentroid(:,3) == k ));
          
          nudgeX = size(origframe,2) * 0.05;
          nudgeY = size(origframe,1) * 0.05;
          
          subplot(1,3,1);
          image(scaled_frame);
          colormap(gray(256));
          title(['orig, scanaxis:' scanaxis]);
          axis square;
          
          subplot(1,3,2);
          image(segframe);
          colormap(gray(256));
          title('segmented');
          axis square;
          
          subplot(1,3,3);
          imagesc(objframe);
          colormap(gray(256));
          hold on;
              plot(cent(:,1), cent(:,2), 'og');
              text(cent(:,1) + nudgeX, cent(:,2) + nudgeY, num2str(id), 'Color', 'green');
          hold off;
          title('centroid');
          axis square;


          drawnow;

          if contains(upper(videoyn),'Y')
              foo = print('-RGBImage');
              vidStack(:,:,:,k) = foo;
          end
          
          pause(1/fps);
    end         
    
    close(h);
    
%     h = 0;

    if contains(upper(videoyn),'Y')
        myVideo = VideoWriter(videoname);
        myVideo.FrameRate = fps;  % Default 30
        myVideo.Quality = 50;    % Default 75
        open(myVideo);
        writeVideo(myVideo, vidStack);
        close(myVideo);
    end

return;
