function h = plot_slice_volume(stack, xyzscales)
% PLOT_SLICE_VOLUME generates XYZ cutplane representation of an NxMxP stack
%
% h = plot_slice_volume(V)
%
% V = NxMxP matrix
% h = handle to matlab figure
%

if nargin < 2 || isempty(xyzscales)
    xyzscales = [1 1 1];
end

    [m,n,p] = size(stack);
    [X,Y,Z] = meshgrid(1:n,1:m,1:p);
    [xs, ys, zs] = deal(xyzscales(1), xyzscales(2), xyzscales(3));

    h = figure;      
    
    slice(X.*xs, Y.*ys, Z.*zs, double(stack),size(stack,2).*xs/2,size(stack,1).*ys/2,size(stack,3).*zs/2);
    colormap(gray(65535));
    shading(gca, 'interp');
    xlabel('X');
    ylabel('Y');
    zlabel('Z');

    axis square;
    camproj('orthographic');
    cameratoolbar('SetMode', 'orbit');
    
return;
