function save_rotated_tiffstack(nucleoid, stackstyle, centsTF)
% SAVE_ROTATED_TIFFSTACK saves a nucleoid structure as a rotated tiff along the scanaxis
%
% save_rotated_tiffstack(nucleoid, stackstyle, saveTF)
%
% nucleoid = structure outputted by nucleoid_centroid
% stackstyle = [ orig | scaled | {segmented} | objid ]
% centsTF = [ true | {false} ]

if nargin < 3 || isempty(centsTF)
    centsTF = true;
end

if nargin < 2 || isempty(stackstyle)
    stackstyle = 'segmented';
end

if nargin < 1 || isempty(nucleoid)
    error('Need nucleoid structure outputted from nucleoid_centroid');
end

    directory = pwd;
    nuclfile = strrep(nucleoid.Filename, '.tif', ['_' stackstyle '_rotated.tif']);
    filename = fullfile(directory, nuclfile);

    scanaxis = upper(nucleoid.ScanAxis);

    switch lower(stackstyle)
        case 'orig'
            mystack = nucleoid.OrigStack;
        case 'scaled'
            mystack = scale_stack(nucleoid.OrigStack, 'uint8');
        case 'segmented'
            mystack = scale_stack(nucleoid.SegStack, 'uint8');
        case 'objid'
            mystack = scale_stack(nucleoid.ObjIdStack, 'uint8');
        otherwise
            error('Incorrect stackstyle selected. Must be orig, scaled, segmented, or objid');
    end
    
    mystack   = rot_scanaxis(mystack, [], scanaxis, 'scan');

    objIDs    = nucleoid.Cents.ObjID;
    XYZcentroid = [nucleoid.Cents.X nucleoid.Cents.Y nucleoid.Cents.Z];
    
    K = size(mystack,3);
        
    % Need to get the output coordinates back in the lab frame. These will
    % depend on the plane used for the centroids
    switch scanaxis
        case 'X'
            XYZcentroid(:,[1 2 3]) = XYZcentroid(:,[3 2 1]);
        case 'Y'
            XYZcentroid(:,[1 2 3]) = XYZcentroid(:,[1 3 2]);
        case 'Z'
            % nothing needs to change
        otherwise
            % given earlier switch, this should never happen
    end
    
    h = figure;
    
    for k=1:K   % iterate through the frames
        
        myframe   = squeeze(mystack(:,:,k));
        
%          fprintf('frame=%u, max(origframe)= %u, max(scaledframe)= %u, max(segframe)= %u, max(objframe)= %u\n', ...
%                   k, max(double(origframe(:))), max(double(scaled_frame(:))), max(double(segframe(:))), max(double(objframe(:))));
    
%         objs_in_frame = Mcentroid( Mcentroid(:,4) == k );
        
          cent = XYZcentroid( XYZcentroid(:,3) == k, 1:2);
          id = unique(objIDs( XYZcentroid(:,3) == k ));
          
          nudgeX = size(myframe,2) * 0.05;
          nudgeY = size(myframe,1) * 0.05;
          
          image(myframe);
          colormap(gray(256));
          title([stackstyle ', scanaxis:' scanaxis]);
          axis square;
          axis off;
          
          if centsTF
              hold on;
                  plot(cent(:,1), cent(:,2), 'og');
                  text(cent(:,1) + nudgeX, cent(:,2) + nudgeY, num2str(id), 'Color', 'green');
              hold off;          
          end


          drawnow;
          
          foo = print('-r0', '-noui', '-RGBImage');
          vidStack(:,:,:,k) = foo;

    end
    


    imwrite(vidStack(:,:,:,1), filename);
    for k = 2:K
        imwrite(vidStack(:,:,:,k), filename, 'WriteMode', 'append');    
    end

    close(h);

return;
