function [stackout, scales] = scale_stack(stackin, typeout)
% SCALE_STACK scales a 3D intensity stack using stack statistics
%
% [stackout, scales] = scale_stack(stackin, typeout)
%
% Inputs:
% "stackin", MxNxP matrix containing originial imaging-stack data
% "typeout', [ {double} | uint8 | uint16 ], sets output typef for stackout
%
% Outputs:
% "stackout", MxNxP matrix containing normalized stack output
% "scales", returns scaling factors used to normalize the original stack
%

    if ~exist('typeout') || isempty(typeout)
        typeout = 'double';
    end
    
    stackin = double(stackin);

    scales.min = min(stackin(:));
    scales.max = max(stackin(:));
        
    neutstack = stackin - scales.min; % subtract off the minimum pixel value
    
    stackout = neutstack ./ (scales.max-scales.min); % scale by class

    switch typeout
        case 'double'
            % no change, already normalized to 1
        case 'uint8'
            stackout = uint8(stackout * (2^8 - 1));  
        case 'uint16'
            stackout = uint16(stackout * (2^16 - 1));
        otherwise
            error('Type not defined here.');
    end
    
%     fprintf('max(stackout)= %u\n', max(stackout(:)));
    
    return;
    
    