function outs = section_stats(ins, tplocs)

    ObjID_list = unique(ins.ObjID);

    for k = 1:length(ObjID_list)
        
        thisobj = ( ins.ObjID == ObjID_list(k) );
        
        mypitch= ins.Pitch(thisobj);
        dtheta = ins.Handed(thisobj);
        tendril_perv_locs = tplocs{k};
        
        
        % How many changes in handedness?
        Np = length(tendril_perv_locs);

        % Segmenting the pitch measurements between perversions
        if Np == 0    
            % If there are no changes in handedness, theres only one section
            sections{1,1} = mypitch;
            sectionID = 1;
        elseif Np == 1
            % One change in handedness has two sections
            sections{1,1} = mypitch(1:tendril_perv_locs(1)-1);    
            sections{2,1} = mypitch(tendril_perv_locs(1)+1:end);            
            sectionID = [1;2];
        elseif Np > 1
            % multiple changes in handedness has multiple changes
            for s = 1:Np            
                if s==1
                    sections{s,1} = mypitch(1:tendril_perv_locs(s)-1);
                elseif s > 1 && s < Np
                    sections{s,1} = mypitch(tendril_perv_locs(s-1)+1:tendril_perv_locs(s)-1);
                elseif s==Np
                    sections{s,1} = mypitch(tendril_perv_locs(s)+1:end);
                end           
                sectionID(s,1) = s;
            end
        end
        
        pitchstats.ObjID = repmat(ObjID_list(k),length(sections),1);
        pitchstats.SectionID = sectionID(:);
        pitchstats.Pitch = sections;
        pitchstats.N = cell2mat(cellfun(@length, sections, 'UniformOutput', false));
        pitchstats.Mean = cell2mat(cellfun(@mean, sections, 'UniformOutput', false));
        pitchstats.Std = cell2mat(cellfun(@std, sections, 'UniformOutput', false));
        pitchstats.Median = cell2mat(cellfun(@median, sections, 'UniformOutput', false));
        pitchstats.Mad = cell2mat(cellfun(@(x)mad(x,1), sections, 'UniformOutput', false));
        
        if k==1
            PitchTable = struct2table(pitchstats);
        else
            temp = struct2table(pitchstats);
            PitchTable = vertcat(PitchTable, temp);
        end            
        
        clear pitchstats sections;
    end
    
    outs = PitchTable;    
    
    outs.Properties.Description = 'Nucleoid Sectional Data (between tendril-perversions)';
    outs.Properties.VariableUnits{'Pitch'} = 'um';
    outs.Properties.VariableUnits{'Mean'} = 'um';
    outs.Properties.VariableUnits{'Std'} = 'um';
    outs.Properties.VariableUnits{'Median'} = 'um';
    outs.Properties.VariableUnits{'Mad'} = 'um';
    outs.Properties.VariableDescriptions{'Mad'} = 'Median Absolute Deviation';
    
    return
    