function testnucl = test_nucleoids(testdata, resultsdir, testvideoTF)

if nargin < 3 || isempty(testvideoTF)
    testvideoTF = false;
end

if nargin < 2 || isempty(resultsdir)
    resultsdir = 'test_nucleoids';
end    

if nargin < 1 || isempty(testdata)
    testdata = '~/src/micro6/nucleoids/testdata/*.tif';

    try 
        dir(testdata);
    catch
        error('Default test-data path does not exist or contains no tif files for testing.');
    end
end


[status,msg] = mkdir(resultsdir);
cd(resultsdir);

disp('Copying real nucleoid datasets used for testing code...');
[status,msg] = copyfile(testdata, '.');

disp('Constructing modeled test data....');
model_volume;

% [status,msg] = mkdir(plotdir);

testfiles = {'test_gauss_3d.tif'                          , 'Y', [0.1 0.5 1] ; 
             'twisted_gauss_3dx.tif'                      , 'X', [1.4 0.333 0.73] ; 
             'twisted_gauss_3dy.tif'                      , 'Y', [1 1 1] ; 
             'twisted_gauss_3dz.tif'                      , 'Z', [1 1 1] ;              
             'tendril_3dx.tif'                            , 'X', [0.6 0.3 1] ; 
             'tendril_3dy.tif'                            , 'Y', [0.5 0.5 1.2] ;
             'tendril_3dz.tif'                            , 'Z', [1 1 1] ;
             '1_1min_300nmTP10.tif'                       , 'Z', [1 1 1] ; 
             'dhns_1.tif'                                 , 'Y', [1 1 1] ;
             'duality_slide9A_3Dstack_A1.tif'             , 'Y', [1 1 1] ;
             'narrow_38.tif'                              , 'Y', [1 1 1] ;
             'narrow_LF_3Dstack_A1_ROI4.tif'              , 'Y', [1 1 1] ; 
             'nucleoid1.tif'                              , 'Y', [1 1 1] ;
             'nucleoid2.tif'                              , 'Y', [1 1 1] ;
             'nucleoid3.tif'                              , 'Y', [1 1 1] ;
             'raw_1min_300nm1_w2mCherry_to_camera_t10.tif', 'Y', [1 1 1] ;
             'walled_3Dstack_A1_ROI1.tif'                 , 'Y', [1 1 1] ;
             'wide_57.tif'                                , 'Y', [1 1 1] ;
 '10_Image 31_Airyscan Processing-crop2_rotate13_bin2x2.tif', 'X', [1 1 1] };

filenames = testfiles(:,1);
scanaxis = testfiles(:,2);
xyz_scales = testfiles(:,3);

Nfiles = length(filenames);

for k = 1:Nfiles
    myfile = filenames{k};
    myxyzscale = xyz_scales{k};
    myscanaxis = scanaxis{k};
    sfactor = 2;
    normvolreject = 0.07;
    watershed_threshold = 0.5;
    
    disp(['Working on ' myfile]);
    
    testnucl(k) = nucleoid_centroid(myfile, myxyzscale, sfactor, normvolreject, watershed_threshold, myscanaxis);
    
    
    stack = scale_stack(testnucl(k).OrigStack);
    rotstack = rot_scanaxis(stack, myxyzscale, myscanaxis, 'scan');
    segstack = rot_scanaxis(testnucl(k).SegStack, myxyzscale, myscanaxis, 'scan');
    idstack = rot_scanaxis(testnucl(k).ObjIdStack, myxyzscale, myscanaxis, 'scan');
        
%     play_stack(scale_stack(rotstack), 20, 'X', 'y');
%     play_stack(scale_stack(rotstack), 20, 'Y', 'y');
%     play_stack(scale_stack(rotstack), 20, 'Z', 'y');

    h(1) = plot_montage(rotstack);
    drawnow;
    
    h(2) = plot_slice_volume(scale_stack(testnucl(k).OrigStack), myxyzscale);
    drawnow;
    
    h(3) = plot_centroids3d(testnucl(k));
    drawnow;
    
    h(4) = plot_centroidproj(testnucl(k), myscanaxis);
    drawnow;
    
    h(5) = plot_pitch(testnucl(k));
    drawnow;
    
    newfile = strrep(myfile, '.tif', '');
    mkdir(newfile);
    movefile(myfile, newfile);

    newfilenamebase = [newfile filesep newfile '_' myscanaxis];
    
    for m = 1:length(h)
        saveas(h(m), [newfilenamebase '_plot' num2str(m) '.fig'], 'fig');
        saveas(h(m), [newfilenamebase '_plot' num2str(m) '.png'], 'png');
        save_for_pymol(testnucl(k), [newfilenamebase '_pymol.txt']);
    end
    
    % save the nucleoid output to a matlab structure
    foo = testnucl(k);
    save([newfilenamebase '.mat'], '-struct', 'foo');    
    close(h);
    
    % save the outputted nucleoid stacks to new tiff files
    savetiff(rotstack, [newfilenamebase '_rot_scaled.tif']);
    savetiff(segstack, [newfilenamebase '_rot_segmented.tif']);
    savetiff(idstack, [newfilenamebase '_rot_objid.tif']);
    
    if testvideoTF && ~mod(k,5)
        plot_nucleoid_centroid(testnucl(k), 15, 'y', [newfilenamebase '.avi']);
    end

end

% testGaussSpiral = nucleoid_centroid('twisted_gauss_3d.tif', [1 1 1], 0.07, 'Y');

