function [tiffmatrix, tiffmetadata] = tiff2matrix(tiff)
% TIFF2MATRIX converts a 3D tiff file into an MxNxP matrix
%
% [tiffmatrix, tiffmetadata] = tiff2matrix(tiff)
%
%  Inputs:
%  "tiff" is a tiff file containing one or more embedded images
%  
%  Outputs:
%  "tiffmatrix", MxNxP matrix containing original imaging data
%  "tiffmetadata", structure containing metadata from images extracted from
%     tiff file. The number of rows in the structure corresponds to the number
%     of pages, P, in the output tiffmatrix.
%

tiffmetadata= imfinfo(tiff, 'tiff');
N = length(tiffmetadata);

for k = 1:N
    tiffmatrix(:,:,k) = imread(tiff,k);
end

tiffmatrix = double(tiffmatrix);

return;

% function for writing out stderr log messages
function logentry(txt)
    logtime = clock;
    logtimetext = [ '(' num2str(logtime(1),  '%04i') '.' ...
                   num2str(logtime(2),        '%02i') '.' ...
                   num2str(logtime(3),        '%02i') ', ' ...
                   num2str(logtime(4),        '%02i') ':' ...
                   num2str(logtime(5),        '%02i') ':' ...
                   num2str(floor(logtime(6)), '%02i') ') '];
     headertext = [logtimetext 'tiff2matrix: '];
     
     fprintf('%s%s\n', headertext, txt);
     
     return;    
